@@ -21,8 +21,8 @@ import java.util.List;
 import java.util.function.Consumer;
 
 import elemental2.promise.Promise;
-import org.guvnor.structure.contributors.Contributor;
-import org.guvnor.structure.contributors.ContributorType;
+import org.uberfire.security.Contributor;
+import org.uberfire.security.ContributorType;
 import org.jboss.errai.bus.client.api.messaging.Message;
 import org.jboss.errai.common.client.api.ErrorCallback;
 
@@ -40,4 +40,8 @@ public interface ContributorsListService {
     void getValidUsernames(Consumer<List<String>> validUsernamesConsumer);
 
     void onExternalChange(final Consumer<Collection<Contributor>> contributorsConsumer);
+
+    boolean requireValidUsername();
+
+    String getInvalidNameMessageConstant();
 }
