@@ -16,6 +16,8 @@
 
 package org.kie.workbench.common.stunner.core.client.canvas.controls;
 
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
+
 /**
  * A canvas control.
  * It can implement <code>IsWidget</code> if the control have to include views outside the canvas itself,
@@ -23,13 +25,18 @@ package org.kie.workbench.common.stunner.core.client.canvas.controls;
  */
 public interface CanvasControl<C> {
 
-    /**
-     * This method is called when the control is enabled for a canvas.
-     */
-    void enable(final C context);
+    interface SessionAware<S extends ClientSession> {
+
+        void bind(S session);
+    }
 
     /**
-     * This method is called when the control is disabled for a canvas.
+     * This method is called when the control is initialized for a given context.
      */
-    void disable();
+    void init(C context);
+
+    /**
+     * This method is called when the control is being destroyed.
+     */
+    void destroy();
 }
