@@ -16,14 +16,16 @@
 
 package org.kie.workbench.common.stunner.core.client.canvas.command;
 
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.Optional;
 import java.util.function.BiPredicate;
 
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
-import org.kie.workbench.common.stunner.core.command.impl.CompositeCommandImpl;
+import org.kie.workbench.common.stunner.core.command.impl.CompositeCommand;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
@@ -52,13 +54,14 @@ public class DrawCanvasCommand extends AbstractCanvasCommand {
         final Graph graph = context.getGraphIndex().getGraph();
         final String shapeSetId = getShapeSetId(context);
 
-        final CompositeCommandImpl.CompositeCommandBuilder<AbstractCanvasHandler, CanvasViolation> commandBuilder =
-                new CompositeCommandImpl.CompositeCommandBuilder<AbstractCanvasHandler, CanvasViolation>().forward();
+        final CompositeCommand.Builder<AbstractCanvasHandler, CanvasViolation> commandBuilder =
+                new CompositeCommand.Builder<AbstractCanvasHandler, CanvasViolation>().forward();
 
         // Aggregate all nodes in the parent-child-dock hierarchy.
         childrenTraverseProcessor
                 .traverse(graph,
                           new AbstractChildrenTraverseCallback<Node<View, Edge>, Edge<Child, Node>>() {
+                              private Map<String, Boolean> processedNodes = new HashMap<>();
 
                               @Override
                               public void startNodeTraversal(final Node<View, Edge> node) {
@@ -93,23 +96,57 @@ public class DrawCanvasCommand extends AbstractCanvasCommand {
                                   return true;
                               }
 
-                              private void addNode(final Node<View, Edge> node) {
+                              private void addNode(final Node node) {
+                                  //skip in case the node was already processed
+                                  if (processedNodes.containsKey(node.getUUID())) {
+                                      return;
+                                  }
+
                                   commandBuilder.addCommand(new AddCanvasNodeCommand(node,
                                                                                      shapeSetId));
+                                  addProcessedNode(node);
                               }
 
                               private void addChildNode(final Node<View, Edge> parent,
                                                         final Node<View, Edge> node) {
+                                  //skip in case the node was already processed
+                                  if (processedNodes.containsKey(node.getUUID())) {
+                                      return;
+                                  }
+
+                                  //check whether the parent was processed, is must be processed before child node
+                                  if (!processedNodes.containsKey(parent.getUUID())) {
+                                      addNode(parent);
+                                  }
+
                                   commandBuilder.addCommand(new AddCanvasChildNodeCommand(parent,
                                                                                           node,
                                                                                           shapeSetId));
+                                  addProcessedNode(node);
                               }
 
                               private void addDockedNode(final Node<View, Edge> parent,
                                                          final Node<View, Edge> node) {
+                                  //check whether the dock parent was processed, is must be processed before docked the node
+                                  if (!processedNodes.containsKey(parent.getUUID())) {
+                                      addNode(parent);
+                                  }
+
                                   commandBuilder.addCommand(new AddCanvasDockedNodeCommand(parent,
                                                                                            node,
                                                                                            shapeSetId));
+                                  addProcessedNode(node);
+                              }
+
+                              private void addProcessedNode(Node<View, Edge> node) {
+                                  processedNodes.put(node.getUUID(), true);
+                              }
+
+                              @Override
+                              public void endGraphTraversal() {
+                                  super.endGraphTraversal();
+                                  processedNodes.clear();
+                                  processedNodes = null;
                               }
                           });
 
@@ -126,9 +163,7 @@ public class DrawCanvasCommand extends AbstractCanvasCommand {
                               }
                           });
 
-        return commandBuilder
-                .build()
-                .execute(context);
+        return executeCommands(context, commandBuilder);
     }
 
     @Override
@@ -149,4 +184,16 @@ public class DrawCanvasCommand extends AbstractCanvasCommand {
     private String getShapeSetId(final AbstractCanvasHandler context) {
         return context.getDiagram().getMetadata().getShapeSetId();
     }
+
+    protected CommandResult<CanvasViolation> executeCommands(AbstractCanvasHandler context,
+                                                             CompositeCommand.Builder<AbstractCanvasHandler, CanvasViolation> commandBuilder) {
+        return commandBuilder
+                .build()
+                .execute(context);
+    }
+
+    @Override
+    public String toString() {
+        return getClass().getSimpleName();
+    }
 }
