@@ -23,13 +23,14 @@ import org.kie.workbench.common.stunner.core.client.shape.Shape;
 import org.kie.workbench.common.stunner.core.client.shape.factory.ShapeDefTestStubs.TestShapeDefFactoryStub;
 import org.kie.workbench.common.stunner.core.client.shape.factory.ShapeDefTestStubs.TestShapeDefType1;
 import org.kie.workbench.common.stunner.core.client.shape.factory.ShapeDefTestStubs.TestShapeDefType2;
+import org.kie.workbench.common.stunner.core.definition.adapter.binding.BindableAdapterUtils;
 import org.kie.workbench.common.stunner.core.definition.shape.ShapeGlyph;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
@@ -63,7 +64,7 @@ public class DelegateShapeFactoryTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testDelegate1() {
-        final String definition1Id = DelegateShapeFactory.getDefinitionId(Definition1.class);
+        final String definition1Id = BindableAdapterUtils.getDefinitionId(Definition1.class);
         tested.delegate(Definition1.class,
                         shapeDef1,
                         () -> shapeDefFactoryStub);
@@ -71,18 +72,26 @@ public class DelegateShapeFactoryTest {
         assertNotNull(shape);
         assertEquals(shape1,
                      shape);
+
         final ShapeGlyph glyph = (ShapeGlyph) tested.getGlyph(definition1Id);
         assertNotNull(glyph);
         assertEquals(definition1Id,
                      glyph.getDefinitionId());
         assertEquals(tested,
                      glyph.getFactorySupplier().get());
+
+        final ShapeGlyph glyph2 = (ShapeGlyph) tested.getGlyph(definition1Id, ShapeFactory.GlyphConsumer.class);
+        assertNotNull(glyph2);
+        assertEquals(definition1Id,
+                     glyph2.getDefinitionId());
+        assertEquals(tested,
+                     glyph2.getFactorySupplier().get());
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testDelegate2() {
-        final String definition2Id = DelegateShapeFactory.getDefinitionId(Definition2.class);
+        final String definition2Id = BindableAdapterUtils.getDefinitionId(Definition2.class);
         tested.delegate(Definition2.class,
                         shapeDef2,
                         () -> shapeDefFactoryStub);
@@ -90,12 +99,20 @@ public class DelegateShapeFactoryTest {
         assertNotNull(shape);
         assertEquals(shape2,
                      shape);
+
         final ShapeGlyph glyph = (ShapeGlyph) tested.getGlyph(definition2Id);
         assertNotNull(glyph);
         assertEquals(definition2Id,
                      glyph.getDefinitionId());
         assertEquals(tested,
                      glyph.getFactorySupplier().get());
+
+        final ShapeGlyph glyph2 = (ShapeGlyph) tested.getGlyph(definition2Id, ShapeFactory.GlyphConsumer.class);
+        assertNotNull(glyph2);
+        assertEquals(definition2Id,
+                     glyph2.getDefinitionId());
+        assertEquals(tested,
+                     glyph2.getFactorySupplier().get());
     }
 
     @Test(expected = RuntimeException.class)
