@@ -17,6 +17,7 @@
 package org.kie.workbench.common.stunner.core.registry.impl;
 
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.LinkedList;
@@ -27,7 +28,7 @@ import org.kie.workbench.common.stunner.core.registry.rule.RuleHandlerRegistry;
 import org.kie.workbench.common.stunner.core.rule.RuleEvaluationHandler;
 import org.kie.workbench.common.stunner.core.rule.ext.RuleExtensionHandler;
 
-class RuleHandlerRegistryImpl implements RuleHandlerRegistry {
+public class RuleHandlerRegistryImpl implements RuleHandlerRegistry {
 
     private final Map<Class<?>, List<RuleEvaluationHandler>> handlers = new HashMap<>(15);
     private final Map<Class<?>, RuleExtensionHandler> extensionHandlers = new LinkedHashMap<>();
@@ -43,7 +44,8 @@ class RuleHandlerRegistryImpl implements RuleHandlerRegistry {
 
     @Override
     public Collection<RuleEvaluationHandler> getHandlersByContext(final Class<?> contextType) {
-        return handlers.get(contextType);
+        return handlers.getOrDefault(contextType,
+                                     Collections.emptyList());
     }
 
     @Override
@@ -52,6 +54,12 @@ class RuleHandlerRegistryImpl implements RuleHandlerRegistry {
         return (T) extensionHandlers.get(contextType);
     }
 
+    @Override
+    public void clear() {
+        handlers.clear();
+        extensionHandlers.clear();
+    }
+
     @Override
     public boolean isEmpty() {
         return handlers.isEmpty() && extensionHandlers.isEmpty();
