@@ -32,7 +32,7 @@ import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
@@ -44,15 +44,11 @@ import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class CloneNodeCommandTest extends AbstractCloneCommandTest {
 
     protected CloneNodeCommand cloneNodeCommand;
 
-    protected Node<View, Edge> candidate;
-
-    protected Node<View, Edge> parent;
-
     protected Point2D position;
 
     @Captor
@@ -62,11 +58,9 @@ public class CloneNodeCommandTest extends AbstractCloneCommandTest {
     public void setUp() {
         super.setUp();
 
-        candidate = graphInstance.containerNode;
-        parent = graphInstance.parentNode;
-        candidate.setContent(candidateContent);
+        graphInstance.containerNode.setContent(candidateContent);
         this.position = new Point2D(1, 1);
-        this.cloneNodeCommand = new CloneNodeCommand(candidate, parent.getUUID(), position, null, childrenTraverseProcessorManagedInstance);
+        this.cloneNodeCommand = new CloneNodeCommand(graphInstance.containerNode, graphInstance.parentNode.getUUID(), position, null, childrenTraverseProcessorManagedInstance);
     }
 
     @Test
@@ -84,7 +78,7 @@ public class CloneNodeCommandTest extends AbstractCloneCommandTest {
         AddChildNodeCommand addChildCommand = (AddChildNodeCommand) cloneNodeCommand.getCommands().stream().filter(command -> command instanceof AddChildNodeCommand).findFirst().get();
         assertNotNull(addChildCommand);
         assertEquals(addChildCommand.getCandidate(), clone);
-        assertEquals(addChildCommand.getParent(graphCommandExecutionContext), parent);
+        assertEquals(addChildCommand.getParent(graphCommandExecutionContext), graphInstance.parentNode);
         if (addChildCommand.getLocation() != null) {
             assertEquals(addChildCommand.getLocation().getX(), position.getX(), 0);
             assertEquals(addChildCommand.getLocation().getY(), position.getY(), 0);
