@@ -16,6 +16,8 @@
 
 package org.kie.workbench.common.stunner.core.rule.handler.impl;
 
+import java.util.Collection;
+import java.util.Collections;
 import java.util.HashSet;
 
 import org.junit.Before;
@@ -26,12 +28,14 @@ import org.kie.workbench.common.stunner.core.rule.RuleViolations;
 import org.kie.workbench.common.stunner.core.rule.context.NodeContainmentContext;
 import org.kie.workbench.common.stunner.core.rule.impl.CanContain;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class NodeContainmentEvaluationHandlerTest extends AbstractGraphRuleHandlerTest {
 
     private final static CanContain RULE = new CanContain("r1",
@@ -47,12 +51,14 @@ public class NodeContainmentEvaluationHandlerTest extends AbstractGraphRuleHandl
     @Mock
     NodeContainmentContext context;
     private NodeContainmentEvaluationHandler tested;
+    private Collection candidates;
 
     @Before
     @SuppressWarnings("unchecked")
     public void setup() throws Exception {
         super.setup();
         when(context.getParent()).thenReturn(element);
+        candidates = Collections.singletonList(candidate);
         tested = new NodeContainmentEvaluationHandler(definitionManager,
                                                       CONTAINMENT_HANDLER);
     }
@@ -61,7 +67,7 @@ public class NodeContainmentEvaluationHandlerTest extends AbstractGraphRuleHandl
     @SuppressWarnings("unchecked")
     public void testAcceptSuccess() {
         when(context.getParent()).thenReturn(element);
-        when(context.getCandidate()).thenReturn(candidate);
+        when(context.getCandidates()).thenReturn(candidates);
         final boolean accepts = tested.accepts(RULE,
                                                context);
         assertTrue(accepts);
@@ -71,7 +77,7 @@ public class NodeContainmentEvaluationHandlerTest extends AbstractGraphRuleHandl
     @SuppressWarnings("unchecked")
     public void testAcceptFailed() {
         when(context.getParent()).thenReturn(parent);
-        when(context.getCandidate()).thenReturn(candidate);
+        when(context.getCandidates()).thenReturn(candidates);
         final boolean accepts = tested.accepts(RULE,
                                                context);
         assertFalse(accepts);
@@ -80,7 +86,7 @@ public class NodeContainmentEvaluationHandlerTest extends AbstractGraphRuleHandl
     @Test
     @SuppressWarnings("unchecked")
     public void testEvaluateSuccess() {
-        when(context.getCandidate()).thenReturn(candidate);
+        when(context.getCandidates()).thenReturn(candidates);
         final RuleViolations violations = tested.evaluate(RULE,
                                                           context);
         assertNotNull(violations);
@@ -90,7 +96,7 @@ public class NodeContainmentEvaluationHandlerTest extends AbstractGraphRuleHandl
     @Test
     @SuppressWarnings("unchecked")
     public void testEvaluateFailed() {
-        when(context.getCandidate()).thenReturn(candidate);
+        when(context.getCandidates()).thenReturn(candidates);
         final RuleViolations violations = tested.evaluate(RULE_INVALID,
                                                           context);
         assertNotNull(violations);
