@@ -22,13 +22,13 @@ import java.util.Set;
 
 import javax.validation.Valid;
 
-import org.jboss.errai.common.client.api.annotations.MapsTo;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.CircleDimensionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
-import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.variables.AdvancedData;
+import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Category;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Labels;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.MorphBase;
@@ -40,45 +40,58 @@ public abstract class BaseGateway implements BPMNViewDefinition {
     @Category
     public static final transient String category = BPMNCategories.GATEWAYS;
 
-    @PropertySet
+    @Property
     @FormField
     @Valid
     protected BPMNGeneralSet general;
 
-    @PropertySet
+    @Property
     @Valid
     protected BackgroundSet backgroundSet;
 
-    @PropertySet
+    @Property
     protected FontSet fontSet;
 
-    @PropertySet
+    @Property
     protected CircleDimensionSet dimensionsSet;
 
+    @Property
+    @FormField(
+            afterElement = "dimensionSet"
+    )
+    @Valid
+    protected AdvancedData advancedData;
+
     @Labels
-    protected final Set<String> labels = new HashSet<String>() {{
-        add("all");
-        add("lane_child");
-        add("sequence_start");
-        add("sequence_end");
-        add("choreography_sequence_start");
-        add("choreography_sequence_end");
-        add("fromtoall");
-        add("GatewaysMorph");
-        add("cm_nop");
-    }};
+    protected final Set<String> labels = new HashSet<>();
 
     public BaseGateway() {
+        initLabels();
     }
 
-    public BaseGateway(final @MapsTo("general") BPMNGeneralSet general,
-                       final @MapsTo("backgroundSet") BackgroundSet backgroundSet,
-                       final @MapsTo("fontSet") FontSet fontSet,
-                       final @MapsTo("dimensionsSet") CircleDimensionSet dimensionsSet) {
+    public BaseGateway(BPMNGeneralSet general,
+                       BackgroundSet backgroundSet,
+                       FontSet fontSet,
+                       CircleDimensionSet dimensionsSet,
+                       AdvancedData advancedData) {
+        this();
         this.general = general;
         this.backgroundSet = backgroundSet;
         this.fontSet = fontSet;
         this.dimensionsSet = dimensionsSet;
+        this.advancedData = advancedData;
+    }
+
+    protected void initLabels() {
+        labels.add("all");
+        labels.add("lane_child");
+        labels.add("sequence_start");
+        labels.add("sequence_end");
+        labels.add("choreography_sequence_start");
+        labels.add("choreography_sequence_end");
+        labels.add("fromtoall");
+        labels.add("GatewaysMorph");
+        labels.add("cm_nop");
     }
 
     public String getCategory() {
@@ -121,29 +134,38 @@ public abstract class BaseGateway implements BPMNViewDefinition {
         this.dimensionsSet = dimensionsSet;
     }
 
+    public AdvancedData getAdvancedData() {
+        return advancedData;
+    }
+
+    public void setAdvancedData(AdvancedData advancedData) {
+        this.advancedData = advancedData;
+    }
+
     @Override
     public int hashCode() {
-        return HashUtil.combineHashCodes(Objects.hashCode(general),
+        return HashUtil.combineHashCodes(Objects.hashCode(getClass()),
+                                         Objects.hashCode(general),
                                          Objects.hashCode(backgroundSet),
                                          Objects.hashCode(fontSet),
                                          Objects.hashCode(dimensionsSet),
+                                         Objects.hashCode(advancedData),
                                          Objects.hashCode(labels));
     }
 
     @Override
     public boolean equals(Object o) {
+        if (this == o) {
+            return true;
+        }
         if (o instanceof BaseGateway) {
             BaseGateway other = (BaseGateway) o;
-            return Objects.equals(general,
-                                  other.general) &&
-                    Objects.equals(backgroundSet,
-                                   other.backgroundSet) &&
-                    Objects.equals(fontSet,
-                                   other.fontSet) &&
-                    Objects.equals(dimensionsSet,
-                                   other.dimensionsSet) &&
-                    Objects.equals(labels,
-                                   other.labels);
+            return Objects.equals(general, other.general) &&
+                    Objects.equals(backgroundSet, other.backgroundSet) &&
+                    Objects.equals(fontSet, other.fontSet) &&
+                    Objects.equals(dimensionsSet, other.dimensionsSet) &&
+                    Objects.equals(advancedData, other.advancedData) &&
+                    Objects.equals(labels, other.labels);
         }
         return false;
     }
