@@ -29,7 +29,8 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Circ
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationAttributeSet;
-import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.variables.AdvancedData;
+import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Category;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Labels;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.MorphBase;
@@ -45,24 +46,31 @@ public abstract class BaseStartEvent implements BPMNViewDefinition,
     @Labels
     protected final Set<String> labels = new HashSet<String>();
 
-    @PropertySet
+    @Property
     @FormField
     @Valid
     protected BPMNGeneralSet general;
 
-    @PropertySet
+    @Property
     @Valid
     protected BackgroundSet backgroundSet;
 
-    @PropertySet
+    @Property
     protected FontSet fontSet;
 
-    @PropertySet
+    @Property
     private CircleDimensionSet dimensionsSet;
 
-    @PropertySet
+    @Property
     private SimulationAttributeSet simulationSet;
 
+    @Property
+    @FormField(
+            afterElement = "simulationSet"
+    )
+    @Valid
+    protected AdvancedData advancedData;
+
     public BaseStartEvent() {
         initLabels();
     }
@@ -71,17 +79,20 @@ public abstract class BaseStartEvent implements BPMNViewDefinition,
                           final BackgroundSet backgroundSet,
                           final FontSet fontSet,
                           final CircleDimensionSet dimensionsSet,
-                          final SimulationAttributeSet simulationSet) {
+                          final SimulationAttributeSet simulationSet,
+                          final AdvancedData advancedData) {
         this();
         this.general = general;
         this.backgroundSet = backgroundSet;
         this.fontSet = fontSet;
         this.dimensionsSet = dimensionsSet;
         this.simulationSet = simulationSet;
+        this.advancedData = advancedData;
     }
 
     protected void initLabels() {
         labels.add("all");
+        labels.add("lane_child");
         labels.add("Startevents_all");
         labels.add("Startevents_outgoing_all");
         labels.add("sequence_start");
@@ -161,13 +172,23 @@ public abstract class BaseStartEvent implements BPMNViewDefinition,
         this.simulationSet = simulationSet;
     }
 
+    public AdvancedData getAdvancedData() {
+        return advancedData;
+    }
+
+    public void setAdvancedData(AdvancedData advancedData) {
+        this.advancedData = advancedData;
+    }
+
     @Override
     public int hashCode() {
-        return HashUtil.combineHashCodes(Objects.hashCode(general),
+        return HashUtil.combineHashCodes(Objects.hashCode(getClass()),
+                                         Objects.hashCode(general),
                                          Objects.hashCode(backgroundSet),
                                          Objects.hashCode(fontSet),
                                          Objects.hashCode(dimensionsSet),
                                          Objects.hashCode(simulationSet),
+                                         Objects.hashCode(advancedData),
                                          Objects.hashCode(labels));
     }
 
@@ -180,6 +201,7 @@ public abstract class BaseStartEvent implements BPMNViewDefinition,
                     Objects.equals(fontSet, other.fontSet) &&
                     Objects.equals(dimensionsSet, other.dimensionsSet) &&
                     Objects.equals(simulationSet, other.simulationSet) &&
+                    Objects.equals(advancedData, other.advancedData) &&
                     Objects.equals(labels, other.labels);
         }
         return false;
