@@ -33,6 +33,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Radi
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.gateway.GatewayExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.variables.AdvancedData;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
 import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
@@ -62,6 +63,7 @@ public class InclusiveGateway extends BaseGateway {
              new BackgroundSet(),
              new FontSet(),
              new CircleDimensionSet(new Radius()),
+             new AdvancedData(),
              new GatewayExecutionSet());
     }
 
@@ -69,11 +71,13 @@ public class InclusiveGateway extends BaseGateway {
                             final @MapsTo("backgroundSet") BackgroundSet backgroundSet,
                             final @MapsTo("fontSet") FontSet fontSet,
                             final @MapsTo("dimensionsSet") CircleDimensionSet dimensionsSet,
+                            final @MapsTo("advancedData") AdvancedData advancedData,
                             final @MapsTo("executionSet") GatewayExecutionSet executionSet) {
         super(general,
               backgroundSet,
               fontSet,
-              dimensionsSet);
+              dimensionsSet,
+              advancedData);
         this.executionSet = executionSet;
     }
 
