@@ -17,12 +17,9 @@
 package org.kie.workbench.common.stunner.bpmn.definition.property.variables;
 
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNPropertySet;
-import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.GlobalVariables;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.MetaDataAttributes;
 
 public interface BaseAdvancedData extends BPMNPropertySet {
 
-    GlobalVariables getGlobalVariables();
-
     MetaDataAttributes getMetaDataAttributes();
 }
\ No newline at end of file
