@@ -61,7 +61,8 @@ public class StartEventConverter {
                 .when(StartConditionalEvent.class, this::conditionalEvent)
                 .when(StartEscalationEvent.class, this::escalationEvent)
                 .when(StartCompensationEvent.class, this::compensationEvent)
-                .apply(node).value();
+                .apply(node)
+                .value();
     }
 
     private PropertyWriter noneEvent(Node<View<StartNoneEvent>, ?> n) {
@@ -74,6 +75,7 @@ public class StartEventConverter {
         BPMNGeneralSet general = definition.getGeneral();
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setSimulationSet(definition.getSimulationSet());
 
@@ -96,6 +98,7 @@ public class StartEventConverter {
         BPMNGeneralSet general = definition.getGeneral();
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setSimulationSet(definition.getSimulationSet());
 
@@ -119,6 +122,7 @@ public class StartEventConverter {
         BPMNGeneralSet general = definition.getGeneral();
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setAssignmentsInfo(definition.getDataIOSet().getAssignmentsinfo());
 
@@ -142,6 +146,7 @@ public class StartEventConverter {
         BPMNGeneralSet general = definition.getGeneral();
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setSimulationSet(definition.getSimulationSet());
 
@@ -165,6 +170,7 @@ public class StartEventConverter {
         BPMNGeneralSet general = definition.getGeneral();
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setSimulationSet(definition.getSimulationSet());
 
@@ -188,6 +194,7 @@ public class StartEventConverter {
         BPMNGeneralSet general = definition.getGeneral();
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setAssignmentsInfo( definition.getDataIOSet().getAssignmentsinfo());
 
@@ -211,6 +218,7 @@ public class StartEventConverter {
         BPMNGeneralSet general = definition.getGeneral();
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setSimulationSet(definition.getSimulationSet());
 
@@ -236,6 +244,7 @@ public class StartEventConverter {
         BPMNGeneralSet general = definition.getGeneral();
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setAssignmentsInfo(definition.getDataIOSet().getAssignmentsinfo());
 
