@@ -47,7 +47,8 @@ public class GatewayConverter {
                 .when(ExclusiveGateway.class, this::exclusive)
                 .when(InclusiveGateway.class, this::inclusive)
                 .when(EventGateway.class, this::event)
-                .apply(node).value();
+                .apply(node)
+                .value();
     }
 
     private PropertyWriter inclusive(Node<View<InclusiveGateway>, ?> n) {
@@ -61,6 +62,7 @@ public class GatewayConverter {
         BPMNGeneralSet general = definition.getGeneral();
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         GatewayExecutionSet executionSet = definition.getExecutionSet();
         p.setDefaultRoute(executionSet.getDefaultRoute().getValue());
@@ -81,6 +83,7 @@ public class GatewayConverter {
         BPMNGeneralSet general = definition.getGeneral();
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         GatewayExecutionSet executionSet = definition.getExecutionSet();
         p.setDefaultRoute(executionSet.getDefaultRoute().getValue());
@@ -101,6 +104,7 @@ public class GatewayConverter {
         BPMNGeneralSet general = definition.getGeneral();
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setAbsoluteBounds(n);
 
@@ -117,6 +121,7 @@ public class GatewayConverter {
         BPMNGeneralSet general = definition.getGeneral();
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
+        p.setMetaData(definition.getAdvancedData().getMetaDataAttributes());
 
         p.setAbsoluteBounds(n);
 
