@@ -57,6 +57,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.event.signal.Si
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.Documentation;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.Name;
+import org.kie.workbench.common.stunner.bpmn.definition.property.variables.AdvancedData;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
@@ -113,6 +114,7 @@ public class IntermediateThrowEventConverter extends AbstractConverter implement
                 new Name(p.getName()),
                 new Documentation(p.getDocumentation())
         ));
+        definition.setAdvancedData(new AdvancedData(p.getMetaDataAttributes()));
 
         definition.setDimensionsSet(p.getCircleDimensionSet());
         definition.setFontSet(p.getFontSet());
@@ -144,6 +146,7 @@ public class IntermediateThrowEventConverter extends AbstractConverter implement
                 new Name(p.getName()),
                 new Documentation(p.getDocumentation())
         ));
+        definition.setAdvancedData(new AdvancedData(p.getMetaDataAttributes()));
 
         definition.setDimensionsSet(p.getCircleDimensionSet());
         definition.setFontSet(p.getFontSet());
@@ -177,6 +180,7 @@ public class IntermediateThrowEventConverter extends AbstractConverter implement
                 new Name(p.getName()),
                 new Documentation(p.getDocumentation())
         ));
+        definition.setAdvancedData(new AdvancedData(p.getMetaDataAttributes()));
 
         definition.setDimensionsSet(p.getCircleDimensionSet());
         definition.setFontSet(p.getFontSet());
@@ -208,6 +212,7 @@ public class IntermediateThrowEventConverter extends AbstractConverter implement
                 new Name(p.getName()),
                 new Documentation(p.getDocumentation())
         ));
+        definition.setAdvancedData(new AdvancedData(p.getMetaDataAttributes()));
 
         definition.setDimensionsSet(p.getCircleDimensionSet());
         definition.setFontSet(p.getFontSet());
@@ -239,6 +244,7 @@ public class IntermediateThrowEventConverter extends AbstractConverter implement
                 new Name(p.getName()),
                 new Documentation(p.getDocumentation())
         ));
+        definition.setAdvancedData(new AdvancedData(p.getMetaDataAttributes()));
 
         definition.setDimensionsSet(p.getCircleDimensionSet());
         definition.setFontSet(p.getFontSet());
