@@ -22,9 +22,9 @@ import java.util.HashSet;
 import java.util.Set;
 
 import com.google.gwt.core.client.GWT;
-import com.google.gwt.dom.client.NativeEvent;
 import com.google.gwt.event.dom.client.BlurEvent;
 import com.google.gwt.event.dom.client.BlurHandler;
+import com.google.gwt.event.dom.client.KeyCodes;
 import com.google.gwt.event.dom.client.KeyPressEvent;
 import com.google.gwt.event.dom.client.KeyPressHandler;
 import com.google.gwtmockito.GwtMockito;
@@ -32,22 +32,25 @@ import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
+import org.kie.workbench.common.stunner.bpmn.client.forms.util.StringUtils;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
 
-import static org.junit.Assert.*;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyBoolean;
-import static org.mockito.Matchers.anyChar;
-import static org.mockito.Matchers.anySet;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyBoolean;
+import static org.mockito.ArgumentMatchers.anyChar;
+import static org.mockito.ArgumentMatchers.anySet;
+import static org.mockito.ArgumentMatchers.anyString;
+import static org.mockito.Mockito.doCallRealMethod;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(Parameterized.class)
 public class VariableNameTextBoxTest {
 
-    private static final String ALPHA_NUM_REGEXP = "^[a-zA-Z0-9\\-\\.\\_]*$";
     private static final String ERROR_MESSAGE = "some error";
     private static final String ERROR_REMOVED = "some error reg exp";
     private static final String ERROR_TYPED = "some error reg exp2";
@@ -65,9 +68,6 @@ public class VariableNameTextBoxTest {
     @Mock
     private KeyPressEvent keyPressEvent;
 
-    @Mock
-    private NativeEvent nativeEvent;
-
     private boolean caseSensitive;
 
     private VariableNameTextBox textBox;
@@ -101,13 +101,14 @@ public class VariableNameTextBoxTest {
         doCallRealMethod().when(textBox).setup();
         doCallRealMethod().when(textBox).addBlurHandler(any(BlurHandler.class));
         doCallRealMethod().when(textBox).addKeyPressHandler(any(KeyPressHandler.class));
-        textBox.setRegExp(ALPHA_NUM_REGEXP,
+        textBox.setRegExp(StringUtils.ALPHA_NUM_REGEXP,
                           ERROR_REMOVED,
                           ERROR_TYPED);
         INVALID_VALUES.clear();
         INVALID_VALUES.add("abc");
         INVALID_VALUES.add("CdE");
         INVALID_VALUES.add("a#$%1");
+        INVALID_VALUES.add("a.");
         textBox.setInvalidValues(INVALID_VALUES,
                                  caseSensitive,
                                  ERROR_MESSAGE);
@@ -176,6 +177,9 @@ public class VariableNameTextBoxTest {
         makeValidResult = textBox.makeValidValue("a#b$2%1");
         assertEquals("ab21",
                      makeValidResult);
+        makeValidResult = textBox.makeValidValue("a#b$2%1.3-4_5");
+        assertEquals("ab213-4_5",
+                     makeValidResult);
     }
 
     @Test
@@ -189,6 +193,22 @@ public class VariableNameTextBoxTest {
                                              false);
         assertEquals(null,
                      isValidResult);
+        isValidResult = textBox.isValidValue("-",
+                                             true);
+        assertEquals(null,
+                     isValidResult);
+        isValidResult = textBox.isValidValue("-",
+                                             false);
+        assertEquals(null,
+                     isValidResult);
+        isValidResult = textBox.isValidValue("_",
+                                             true);
+        assertEquals(null,
+                     isValidResult);
+        isValidResult = textBox.isValidValue("_",
+                                             false);
+        assertEquals(null,
+                     isValidResult);
         isValidResult = textBox.isValidValue("aBc",
                                              true);
         if (caseSensitive) {
@@ -218,5 +238,43 @@ public class VariableNameTextBoxTest {
                                              false);
         assertEquals(ERROR_TYPED + ": #$%",
                      isValidResult);
+
+        isValidResult = textBox.isValidValue("a.",
+                                             true);
+        assertEquals(ERROR_MESSAGE,
+                     isValidResult);
+
+        isValidResult = textBox.isValidValue("a.",
+                                             false);
+        assertEquals(ERROR_TYPED + ": .",
+                     isValidResult);
+    }
+
+    @Test
+    public void testKeyEnter() {
+        when(textBox.getKeyCodeFromKeyPressEvent(any(KeyPressEvent.class))).thenReturn(KeyCodes.KEY_ENTER);
+        when(keyPressEvent.isControlKeyDown()).thenReturn(false);
+        when(keyPressEvent.isShiftKeyDown()).thenReturn(false);
+        when(keyPressEvent.getCharCode()).thenReturn((char) 13);
+        when(textBox.getCursorPos()).thenReturn(4);
+        when(textBox.getSelectionLength()).thenReturn(0);
+        when(textBox.getValue()).thenReturn("ab12");
+        when(textBox.getText()).thenReturn("ab12" + (char) 13);
+        textBox.setup();
+        verify(textBox,
+               times(1)).addBlurHandler(blurCaptor.capture());
+        verify(textBox,
+               times(1)).addKeyPressHandler(keyPressCaptor.capture());
+        BlurHandler blurHandler = blurCaptor.getValue();
+        blurHandler.onBlur(blurEvent);
+        verify(textBox,
+               times(1)).isValidValue("ab12" + (char) 13,
+                                      true);
+        verify(textBox,
+               times(1)).makeValidValue("ab12" + (char) 13);
+        verify(textBox,
+               times(1)).setValue("ab12");
+        KeyPressHandler keyPressHandler = keyPressCaptor.getValue();
+        keyPressHandler.onKeyPress(keyPressEvent);
     }
 }
